write_wav

Function write_wav 

pub fn write_wav<TWriter: 'static + Write + Seek>(
    writer: TWriter,
    header: WavHeader,
) -> Result<OpenWavWriter>
Starts writing a wav to a (Write + Seek) struct. Returns an OpenWavWriter struct that is used to write the contents of the wav

Arguments

  • ‘writer’ - The (Write + Seek) struct to write the wav into. It is strongly recommended that this struct implement some form of buffering, such as via a BufWriter
  • ‘header’ - The header information in the wav. This specifies things like sampling rate, sample bit depth, ect